@@ -1,4 +1,5 @@
 ## ----include=FALSE------------------------------------------------------------
+Sys.setenv("ON_CRAN" = "true")
 knitr::opts_chunk$set(comment="")
 if(grepl("windows", tolower(Sys.info()[["sysname"]])))
   knitr::opts_chunk$set(comment="", error =TRUE)
@@ -10,21 +11,21 @@ if(grepl("windows", tolower(Sys.info()[["sysname"]])))
 #  # install.packages("remotes")
 #  remotes::install_github("ropensci/codemetar", ref = "dev")
 
-## ----echo=FALSE, eval=TRUE----------------------------------------------------
-pkg <- "../.."
-codemetar::write_codemeta(pkg = pkg)
-
 ## ----echo=TRUE, eval=FALSE----------------------------------------------------
 #  codemetar::write_codemeta()
 
-## ----eval = TRUE--------------------------------------------------------------
-library("magrittr")
-"../../codemeta.json" %>%
-  details::details(summary = "codemetar's codemeta.json",
-                   lang = "json")
+## ----echo=FALSE, eval = identical(Sys.getenv("NOT_CRAN"), "true")-------------
+#  pkg <- "../.."
+#  codemetar::write_codemeta(pkg = pkg)
 
-## ----echo = FALSE, results='hide'---------------------------------------------
-file.remove(file.path(pkg, "codemeta.json"))
+## ----eval = identical(Sys.getenv("NOT_CRAN"), "true")-------------------------
+#  library("magrittr")
+#  "../../codemeta.json" %>%
+#    details::details(summary = "codemetar's codemeta.json",
+#                     lang = "json")
+
+## ----echo = FALSE, results='hide', eval = identical(Sys.getenv("NOT_CRAN"), "true")----
+#  file.remove(file.path(pkg, "codemeta.json"))
 
 ## ---- echo = FALSE------------------------------------------------------------
 details::details(system.file("templates", "codemeta-github-actions.yml", package = "codemetar"), 
